@@ -1,4 +1,4 @@
-from javaman import JManCon
+from javaman.connexio import JManCon
 
 
 class Usuaris:
